@@ -8,16 +8,15 @@
 @License :   Apache License 2.0
 """
 
-__all__ = ["Evaluator", "build_evalutor", "evaluator_factory"]
+__all__ = ["Evaluator", "build_evaluator", "evaluator_factory", "BaseEvaluator"]
 
 from .evaluator import Evaluator
+from .base_evaluator import BaseEvaluator
 
-evaluator_factory = {
-    'evaluator': Evaluator,
-}
+evaluator_factory = {'evaluator': Evaluator, 'base_evaluator': BaseEvaluator}
 
 
-def build_evalutor(name):
+def build_evaluator(name):
     if name not in evaluator_factory.keys():
         raise ValueError(f'Unknown evaluator name: {name}')
     return evaluator_factory[name]
\ No newline at end of file
