@@ -16,17 +16,15 @@ from .base_sampler import BaseSampler
 
 class RandomSampler(BaseSampler):
     def __init__(self, args) -> None:
-        self.args = args
+        super(RandomSampler, self).__init__(args)
 
     def sample(self, dataset):
         num_items = int(len(dataset) / self.args.num_clients)
         client_data_dict, all_idxs = {}, [i for i in range(len(dataset))]
         for i in range(self.args.num_clients):
-            client_data_dict[i] = list(
-                np.random.choice(all_idxs, num_items, replace=False))
+            client_data_dict[i] = list(np.random.choice(all_idxs, num_items, replace=False))
             all_idxs = list(set(all_idxs) - set(client_data_dict[i]))
 
         return [
-            ClientDataset(dataset, client_data_dict[i])
-            for i in range(self.args.num_clients)
+            ClientDataset(dataset, client_data_dict[i]) for i in range(self.args.num_clients)
         ]
