@@ -9,7 +9,7 @@
 """
 
 from fedhf.component import aggregator_factory, trainer_factory, evaluator_factory, sampler_factory, selector_factory
-from fedhf.model import model_factory, optimizer_factory, criterion_factory
+from fedhf.model import model_factory, optimizer_factory, criterion_factory, lr_schedule_factory
 from fedhf.dataset import dataset_factory
 from fedhf.core import coordinator_factory, server_factory, client_factory
 
@@ -22,10 +22,11 @@ components = {
     'criterion': criterion_factory,
     'dataset': dataset_factory,
     'trainer': trainer_factory,
-    'evalutor': evaluator_factory,
+    'evaluator': evaluator_factory,
     'aggregator': aggregator_factory,
     'sampler': sampler_factory,
     'selector': selector_factory,
+    'lr_schedule': lr_schedule_factory
 }
 
 
